@@ -30,7 +30,7 @@
 #include <gtk/gtk.h>
 #include <gdk/gdk.h>
 
-#include "gnome-i18nP.h"
+#include <glib/gi18n-lib.h>
 
 #include <libgnome/gnome-config.h>
 #include <libgnome/gnome-util.h>
@@ -240,7 +240,7 @@ static void gnome_mdi_destroy (GtkObject *object)
 
 	gnome_mdi_remove_all(mdi, TRUE);
 
-	gtk_object_sink(GTK_OBJECT(object));
+	g_object_ref_sink(GTK_OBJECT(object));
 
 	if(GTK_OBJECT_CLASS(parent_class)->destroy)
 		(* GTK_OBJECT_CLASS(parent_class)->destroy)(object);
@@ -734,9 +734,7 @@ static void app_clone(GnomeMDI *mdi, GnomeApp *app)
 	}
 
 	app_create(mdi, layout_string);
-
-	if(layout_string)
-		g_free(layout_string);
+	g_free(layout_string);
 }
 
 static gint app_close_top (GnomeApp *app, GdkEventAny *event, GnomeMDI *mdi)
@@ -1170,7 +1168,7 @@ gint gnome_mdi_add_view (GnomeMDI *mdi, GnomeMDIChild *child)
 	   when removed from its parent later, as we want it to
 	   stay valid until removed from the child with a call
 	   to gnome_mdi_child_remove_view() */
-	gtk_widget_ref(view);
+	g_object_ref(view);
 
 	if(!GTK_WIDGET_VISIBLE(view))
 		gtk_widget_show(view);
@@ -1248,7 +1246,7 @@ gint gnome_mdi_add_toplevel_view (GnomeMDI *mdi, GnomeMDIChild *child)
 	   when removed from its parent later, as we want it to
 	   stay valid until removed from the child with a call
 	   to gnome_mdi_child_remove_view() */
-	gtk_widget_ref(view);
+	g_object_ref(view);
 
 	if(!GTK_WIDGET_VISIBLE(view))
 		gtk_widget_show(view);
@@ -1452,7 +1450,7 @@ gint gnome_mdi_remove_child (GnomeMDI *mdi, GnomeMDIChild *child, gint force)
 
 	child->parent = NULL;
 
-	gtk_object_sink(GTK_OBJECT(child));
+	g_object_ref_sink(GTK_OBJECT(child));
 
 	if(mdi->mode == GNOME_MDI_MODAL && mdi->children) {
 		GnomeMDIChild *next_child = mdi->children->data;
@@ -1866,9 +1864,7 @@ void gnome_mdi_set_child_menu_path (GnomeMDI *mdi, const gchar *path)
 	g_return_if_fail(mdi != NULL);
 	g_return_if_fail(GNOME_IS_MDI(mdi));
 
-	if(mdi->child_menu_path)
-		g_free(mdi->child_menu_path);
-
+	g_free(mdi->child_menu_path);
 	mdi->child_menu_path = g_strdup(path);
 }
 
@@ -1890,9 +1886,7 @@ void gnome_mdi_set_child_list_path (GnomeMDI *mdi, const gchar *path)
 	g_return_if_fail(mdi != NULL);
 	g_return_if_fail(GNOME_IS_MDI(mdi));
 
-	if(mdi->child_list_path)
-		g_free(mdi->child_list_path);
-
+	g_free(mdi->child_list_path);
 	mdi->child_list_path = g_strdup(path);
 }
 
